@@ -1,4 +1,5 @@
 import { connect } from 'react-redux';
+import { defineMessages, FormattedMessage } from 'react-intl';
 import { Link } from 'react-router';
 import ImmutablePropTypes from 'react-immutable-proptypes';
 import React from 'react';
@@ -10,6 +11,41 @@ import DataTableColumn from '../ui/tables/DataTableColumn';
 import { PageHeader } from '../ui/PageHeader';
 import PlansActions from '../../actions/PlansActions';
 
+const messages = defineMessages({
+  actions: {
+    id: 'ListPlans.actions',
+    defaultMessage: 'Actions'
+  },
+  edit: {
+    id: 'ListPlans.edit',
+    defaultMessage: 'Edit'
+  },
+  delete: {
+    id: 'ListPlans.delete',
+    defaultMessage: 'Delete'
+  },
+  deletingPlanName: {
+    id: 'ListPlans.deletingPlanName',
+    defaultMessage: 'Deleting {planName}...'
+  },
+  plans: {
+    id: 'ListPlans.plans',
+    defaultMessage: 'Plans'
+  },
+  name: {
+    id: 'ListPlans.name',
+    defaultMessage: 'Name'
+  },
+  noPlans: {
+    id: 'ListPlans.noPlans',
+    defaultMessage: 'There are currently no plans'
+  },
+  createNewPlan: {
+    id: 'ListPlans.createNewPlan',
+    defaultMessage: 'Create New Plan'
+  }
+});
+
 class ListPlans extends React.Component {
   constructor() {
     super();
@@ -25,12 +61,14 @@ class ListPlans extends React.Component {
         <td colSpan="2">
           <p></p>
           <p className="text-center">
-            There are currently no Plans
+            <FormattedMessage {...messages.noPlans}/>
           </p>
           <p className="text-center">
             <Link to="/plans/new"
                   query={{tab: 'newPlan'}}
-                  className="btn btn-success">Create New Plan</Link>
+                  className="btn btn-success">
+              <FormattedMessage {...messages.createNewPlan}/>
+            </Link>
           </p>
         </td>
       </tr>
@@ -42,7 +80,8 @@ class ListPlans extends React.Component {
       <Link to="/plans/new"
             query={{tab: 'newPlan'}}
             className="btn btn-primary">
-        <span className="fa fa-plus"/> Create New Plan
+            id="ListPlans__newPlanLink">
+        <span className="fa fa-plus"/>  <FormattedMessage {...messages.createNewPlan}/>
       </Link>
     );
   }
@@ -51,19 +90,27 @@ class ListPlans extends React.Component {
     let plans = this.props.plans.sortBy(plan => plan.name).toArray();
     return (
       <div>
-        <PageHeader>Plans</PageHeader>
+        <PageHeader>
+          <FormattedMessage {...messages.plans}/>
+        </PageHeader>
         <DataTable data={plans}
                    rowsCount={plans.length}
                    noRowsRenderer={this.renderNoPlans.bind(this)}
-                   tableActions={this.renderTableActions}>
-          <DataTableColumn header={<DataTableHeaderCell key="name">Name</DataTableHeaderCell>}
+                   tableActions={this.renderTableActions}
+                   id="ListPlans__plansTable">
+          <DataTableColumn header={<DataTableHeaderCell key="name">
+                                     <FormattedMessage {...messages.name}/>
+                                   </DataTableHeaderCell>}
                            cell={<PlanNameCell
                            data={plans}
                            currentPlanName={this.props.currentPlanName}
                            choosePlan={this.props.choosePlan}/>}/>
-          <DataTableColumn header={<DataTableHeaderCell key="actions">Actions</DataTableHeaderCell>}
-                           cell={<RowActionsCell className="actions text-right"
-                                                 data={plans}/>}/>
+          <DataTableColumn header={<DataTableHeaderCell key="actions">
+                                     <FormattedMessage {...messages.actions}/>
+                                   </DataTableHeaderCell>}
+                           cell={<RowActionsCell
+                           className="actions text-right"
+                           data={plans}/>}/>
         </DataTable>
         {this.props.children}
       </div>
@@ -114,11 +161,15 @@ class RowActionsCell extends React.Component {
           <Link key="edit"
                 to={`/plans/${plan.name}/edit`}
                 query={{tab: 'editPlan'}}
-                className="btn btn-xs btn-default">Edit</Link>
+                className="btn btn-xs btn-default">
+            <FormattedMessage {...messages.edit}/>
+          </Link>
           &nbsp;
           <Link key="delete"
                 to={`/plans/${plan.name}/delete`}
-                className="btn btn-xs btn-danger">Delete</Link>
+                className="btn btn-xs btn-danger ListPlans__editPlanButton">
+            <FormattedMessage {...messages.delete}/>
+          </Link>
         </DataTableCell>
       );
     }
@@ -150,7 +201,10 @@ export class PlanNameCell extends React.Component {
     if(plan.transition === 'deleting') {
       return (
         <DataTableCell {...this.props} colSpan="2" className={plan.transition}>
-          <em>Deleting <strong>{plan.name}</strong>&hellip;</em>
+          <em>
+            <FormattedMessage {...messages.deletingPlanName}
+                              values={{ planName: <strong>{plan.name}</strong>}}/>
+          </em>
         </DataTableCell>
       );
     } else {
